# -*- coding: utf-8 -*-

import os
import datetime
import time
import logging
import logging.handlers
import json
import random

import click
from kombu import Connection
from dropshipping.utils.utils import is_asin_valid
from em_tasks.spapi import Spapi
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.product_util import ProductUtil
import dateutil
import dateutil.parser

from em_celery import logger, get_offer_service, init_db
from em_celery.tasks.spapi_update_item_offers_task import spapi_update_item_offers
from em_celery.tools.spree.amz_offers_update_task_sender import AmzOffersUpdateTaskSender


@click.command('Send spapi update item offers task to worker.')
@click.option('-s', '--store_code', type=str, required=True, help='Store code.')
@click.option('-b', '--broker_url', type=str, required=True, help='Celery worker broker URL.')
@click.option('-m', '--marketplace', type=str, default='us', help='Amazon marketplace to fetch offers.')
@click.option('-t', '--ttl', type=int, default=72, help='Offer alive hours, default is 36.')
@click.option('-f', '--force', is_flag=True, help='Force to update offers.')
@click.option('-q', '--qps', type=float, help='Quantity per second (QPS) to send task.')
def send_amz_offers_update_task(store_code, broker_url, qps, marketplace='us', ttl=72, force=False):
  log_dir = os.path.join(os.path.expanduser('~'), '.em_celery', 'logs')
  if not os.path.isdir(log_dir):
    os.makedirs(log_dir)
  log_path = os.path.join(log_dir, 'amz_offers_update_task_sender.log')
  level = logging.INFO
  max_bytes = 20 * 1024 ** 2
  fh = logging.handlers.RotatingFileHandler(
    log_path, maxBytes=max_bytes, backupCount=5)
  fh.setLevel(level)
  formatter = logging.Formatter('%(asctime)s %(name)s [%(levelname)s]:%(message)s')
  fh.setFormatter(formatter)
  logger.addHandler(fh)

  init_db()

  condition = 'new'
  sender = AmzOffersUpdateTaskSender(store_code, broker_url, qps, marketplace, condition, ttl, force)
  stats = sender.run()

  d_s = datetime.datetime.now().strftime('%Y-%m-%d')
  logger.info("[AmzOffersUpdateTaskSender] Expired: %s, Alive: %s, Date: %s", stats['expired_cnt'], stats['alive_cnt'], d_s)


if __name__ == "__main__":
  send_amz_offers_update_task()
