# -*- coding: utf-8 -*-

import datetime

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.spree.emp_repricer import SpreeEmpRepricer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_emp_offer_filter_config, get_offer_service_config, get_amz_broker_url, get_bot, get_group_chat_id
from em_celery.utils.amz_offers_updater import AmzOffersUpdater


@click.command('Reprice Spree Emp products')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-tc', '--target_currency', type=str, default='USD')
@click.option('-q', '--qps', type=int, default=10)
def reprice(store_code, target_currency='USD', qps=10):
  init_db()
  marketplace = 'us'

  filter_cond = get_emp_offer_filter_config(marketplace)
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  logger.info('[OfferFilters] %s', filter_cond)

  price_rules = {
    'roi': 0.0,
    'ad_cost': 0,
    'transfer_cost': 0,
    'tax_rate': 0
  }

  marketplace = marketplace.lower()
  price_calculator = PriceCalculator(price_rules, target_currency, 0)

  logger.info('[PriceRules] SrcMarketplace: {}, Rules: {}'.format(marketplace, price_rules))

  broker_url = get_amz_broker_url()
  logger.info('[BrokerURL] %s', broker_url)
  updater = AmzOffersUpdater(broker_url, qps, marketplace, 'new')
  tasks_cnt = updater.tasks_cnt()
  callbacks = [updater.update_offers]
  queue_full = False
  # Don't update offers when queue is full
  if tasks_cnt > 10000:
    callbacks = []
    queue_full = True

  start_time = datetime.datetime.now()

  repricer = SpreeEmpRepricer(store_code, offer_service, price_calculator, callbacks)
  repricer.run()

  end_time = datetime.datetime.now()
  total_seconds = round((end_time - start_time).total_seconds())
  if total_seconds > 300:
    stats = repricer.get_stats()
    message = '[AmazonRepricing] Store: {}, Marketplace: {}, QueueFull: {}, Products: {}, Failed: {}, Expired: {}, InStock: {}, OutOfStock: {}, TimeUsed: {}s'.format(
      store_code, marketplace, queue_full, stats['products_cnt'], stats['failed_cnt'], stats['expired_cnt'], stats['in_stock'], stats['out_of_stock'],
      total_seconds)

    bot = get_bot()
    group_chat_id = get_group_chat_id()
    bot.send_message(group_chat_id, message)


if __name__ == "__main__":
  reprice()
