# -*- coding: utf-8 -*-

import os

import click

from em_tasks.utils.product_loaders.asin_loaders import OfferFileAsinLoader
from em_tasks.tools.spapi_offer_updater import SpapiOfferUpdater

from em_celery import logger, get_config, get_spapi, get_offer_service


@click.command('Update Amazon offers by Spapi.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-c', '--condition', required=True, type=str, default='new', help='Product condition, default is new.')
@click.option('-t', '--ttl', required=True, type=int, default=5, help='Offer alive time, default is 5 days.')
@click.option('-f', '--force', is_flag=True, help='Whether to force update offers.')
@click.argument('asins_path')
def update_offers(asins_path, marketplace='us', condition='new', ttl=7, force=False):
  if not asins_path:
    logger.error('asins_file must not be empty')
    return

  asins_path = os.path.abspath(os.path.expanduser(asins_path))
  if not os.path.isfile(asins_path):
    logger.error('[ASINsFileNotFound] %s', asins_path)
    return

  offer_service = get_offer_service()
  asins_loader = OfferFileAsinLoader(asins_path, marketplace, offer_service, condition, ttl, force)

  spapi = get_spapi()
  offer_updater = SpapiOfferUpdater(spapi, marketplace, asins_loader, offer_service)
  offer_updater.run()


if __name__ == "__main__":
  update_offers()
