# -*- coding: utf-8 -*-

import json

import click

from em_tasks.tools.spree.store_amz_products_filter import StoreAmzProductsFilter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_product_service


@click.command('Filter Amazon products in store.')
@click.option('-s', '--store_code', required=True, type=str)
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace of products from.')
@click.option('-e', '--export', is_flag=True, help='Whether to export products to other countries.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
def filter_products(store_code, output_path, marketplace='us', export=False):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  marketplace = marketplace.lower()
  product_service = get_product_service()

  filter_conds = {'export': export}
  products_filter = StoreAmzProductsFilter(store_code, marketplace, product_service, filter_conds)

  with open(output_path, 'w+', encoding='utf-8', errors='ignore') as output_fh:
    for result in products_filter.run():
      for pid, entry in result.items():
        if entry['passed']:
          continue

        output_fh.write(','.join([str(pid), entry['asin'], entry['reason']]))
        output_fh.write("\n")


if __name__ == "__main__":
  filter_products()
